@@ -517,7 +517,7 @@ class UserMixin:
         return users
 
     def user_following(
-        self, user_id: str, use_cache: bool = True, amount: int = 0
+            self, user_id: str, use_cache: bool = True, amount: int = 0
     ) -> Dict[str, UserShort]:
         """
         Get user's followers information
@@ -554,7 +554,8 @@ class UserMixin:
             following = dict(list(following.items())[:amount])
         return following
 
-    def user_followers_gql_chunk(self, user_id: str, max_amount: int = 0, end_cursor: str = None) -> Tuple[List[UserShort], str]:
+    def user_followers_gql_chunk(self, user_id: str, max_amount: int = 0, end_cursor: str = None) -> Tuple[
+        List[UserShort], str]:
         """
         Get user's followers information by Public Graphql API and end_cursor
 
@@ -621,7 +622,8 @@ class UserMixin:
             users = users[:amount]
         return users
 
-    def user_followers_v1_chunk(self, user_id: str, max_amount: int = 0, max_id: str = "") -> Tuple[List[UserShort], str]:
+    def user_followers_v1_chunk(self, user_id: str, max_amount: int = 0, max_id: str = "") -> Tuple[
+        List[UserShort], str]:
         """
         Get user's followers information by Private Mobile API and max_id (cursor)
 
@@ -683,7 +685,7 @@ class UserMixin:
         return users
 
     def user_followers(
-        self, user_id: str, use_cache: bool = True, amount: int = 0
+            self, user_id: str, use_cache: bool = True, amount: int = 0
     ) -> Dict[str, UserShort]:
         """
         Get user's followers
@@ -870,3 +872,155 @@ class UserMixin:
             A boolean value
         """
         return self.mute_stories_from_follow(user_id, True)
+
+    def enable_posts_notifications(self, user_id: str, disable: bool = False) -> bool:
+        """
+        Enable post notifications of a user
+
+        Parameters
+        ----------
+        user_id: str
+            Unique identifier of a User
+        disable: bool, optional
+            Unfavorite when True
+
+        Returns
+        -------
+        bool
+            A boolean value
+        """
+        assert self.user_id, "Login required"
+        user_id = str(user_id)
+        data = self.with_action_data({"user_id": user_id, "_uid": self.user_id})
+        name = "unfavorite" if disable else "favorite"
+        result = self.private_request(f"friendships/{name}/{user_id}/", data)
+        return result["status"] == "ok"
+
+    def disable_posts_notifications(self, user_id: str) -> bool:
+        """
+        Disable post notifications of a user
+
+        Parameters
+        ----------
+        user_id: str
+            Unique identifier of a User
+        Returns
+        -------
+        bool
+            A boolean value
+        """
+        return self.enable_posts_notifications(user_id, True)
+
+    def enable_videos_notifications(self, user_id: str, revert: bool = False) -> bool:
+        """
+        Enable videos notifications of a user
+
+        Parameters
+        ----------
+        user_id: str
+            Unique identifier of a User
+        revert: bool, optional
+            Unfavorite when True
+
+        Returns
+        -------
+        bool
+        A boolean value
+        """
+        assert self.user_id, "Login required"
+        user_id = str(user_id)
+        data = self.with_action_data({"user_id": user_id, "_uid": self.user_id})
+        name = "unfavorite" if revert else "favorite"
+        result = self.private_request(f"friendships/{name}_for_igtv/{user_id}/", data)
+        return result["status"] == "ok"
+
+    def disable_videos_notifications(self, user_id: str) -> bool:
+        """
+        Disable videos notifications of a user
+
+        Parameters
+        ----------
+        user_id: str
+            Unique identifier of a User
+        Returns
+        -------
+        bool
+            A boolean value
+        """
+        return self.enable_videos_notifications(user_id, True)
+
+    def enable_reels_notifications(self, user_id: str, revert: bool = False) -> bool:
+        """
+        Enable reels notifications of a user
+
+        Parameters
+        ----------
+        user_id: str
+            Unique identifier of a User
+        revert: bool, optional
+            Unfavorite when True
+
+        Returns
+        -------
+        bool
+        A boolean value
+        """
+        assert self.user_id, "Login required"
+        user_id = str(user_id)
+        data = self.with_action_data({"user_id": user_id, "_uid": self.user_id})
+        name = "unfavorite" if revert else "favorite"
+        result = self.private_request(f"friendships/{name}_for_clips/{user_id}/", data)
+        return result["status"] == "ok"
+
+    def disable_reels_notifications(self, user_id: str) -> bool:
+        """
+        Disable reels notifications of a user
+
+        Parameters
+        ----------
+        user_id: str
+            Unique identifier of a User
+        Returns
+        -------
+        bool
+            A boolean value
+        """
+        return self.enable_reels_notifications(user_id, True)
+
+    def enable_stories_notifications(self, user_id: str, revert: bool = False) -> bool:
+        """
+        Enable stories notifications of a user
+
+        Parameters
+        ----------
+        user_id: str
+            Unique identifier of a User
+        revert: bool, optional
+            Unfavorite when True
+
+        Returns
+        -------
+        bool
+        A boolean value
+        """
+        assert self.user_id, "Login required"
+        user_id = str(user_id)
+        data = self.with_action_data({"user_id": user_id, "_uid": self.user_id})
+        name = "unfavorite" if revert else "favorite"
+        result = self.private_request(f"friendships/{name}_for_stories/{user_id}/", data)
+        return result["status"] == "ok"
+
+    def disable_stories_notifications(self, user_id: str) -> bool:
+        """
+        Disable stories notifications of a user
+
+        Parameters
+        ----------
+        user_id: str
+            Unique identifier of a User
+        Returns
+        -------
+        bool
+            A boolean value
+        """
+        return self.enable_stories_notifications(user_id, True)
